@@ -1,9 +1,7 @@
+use lib qw(../);
 use strict;
-use warnings;
-
 use Spreadsheet::ParseExcel;
-my $oExcel = Spreadsheet::ParseExcel->new;
-sub PrnBook($);
+my $oExcel = new Spreadsheet::ParseExcel;
 
 #1.1 Normal Excel97
 my $oBook = $oExcel->Parse('Excel/Test97.xls');
@@ -21,7 +19,7 @@ PrnBook($oBook);
 $oBook = $oExcel->Parse('Excel/Test1904_95.xls');
 PrnBook($oBook);
 
-sub PrnBook($)
+sub PrnBook($$)
 {
     my($oBook) = @_;
     my($iR, $iC, $oWkS, $oWkC);
@@ -38,7 +36,7 @@ sub PrnBook($)
             for(my $iC = $oWkS->{MinCol} ;
                             defined $oWkS->{MaxCol} && $iC <= $oWkS->{MaxCol} ; $iC++) {
                 $oWkC = $oWkS->{Cells}[$iR][$iC];
-                print "( $iR , $iC ) =>", $oWkC->Value, "\n" if($oWkC);
+                print "( $iR , $iC ) =>", $oWkC->Value, "\n";
             }
         }
     }
